@@ -7,4 +7,4 @@ class Rep
 end
 
 pp Rep.get('http://whoismyrepresentative.com/getall_mems.php?zip=46544')
-pp Rep.get('http://whoismyrepresentative.com/getall_mems.php', :query => {:zip => 46544})
\ No newline at end of file
+pp Rep.get('http://whoismyrepresentative.com/getall_mems.php', query: { zip: 46544 })
