@@ -2,11 +2,10 @@
 
 require 'pathname'
 require 'net/http'
-require 'net/https'
 require 'uri'
 require 'zlib'
 require 'multi_xml'
-require 'mime/types'
+require 'mini_mime'
 require 'json'
 require 'csv'
 
