@@ -1,9 +1,11 @@
+# frozen_string_literal: true
+
 module HTTParty
   module Logger
     class CurlFormatter #:nodoc:
       TAG_NAME = HTTParty.name
-      OUT      = '>'.freeze
-      IN       = '<'.freeze
+      OUT      = '>'
+      IN       = '<'
 
       attr_accessor :level, :logger
 
@@ -44,7 +46,7 @@ module HTTParty
       end
 
       def log_url
-        http_method = request.http_method.name.split("::").last.upcase
+        http_method = request.http_method.name.split('::').last.upcase
         uri = if request.options[:base_uri]
                 request.options[:base_uri] + request.path.path
               else
